# Project Template for BHKLab Projects

[![Conda Version](https://img.shields.io/conda/v/conda-forge/bhklab-project-template)](https://anaconda.org/conda-forge/bhklab-project-template)
[![PyPI - License](https://img.shields.io/pypi/l/bhklab-project-template)](https://pypi.org/project/bhklab-project-template/)
[![GitHub Release](https://img.shields.io/github/v/release/bhklab/bhklab-project-template)](https://github.com/bhklab/bhklab-project-template/releases)
[![PyPI - Version](https://img.shields.io/pypi/v/bhklab-project-template)](https://pypi.org/project/bhklab-project-template/)

[![Conda Downloads](https://img.shields.io/conda/d/conda-forge/bhklab-project-template)](https://anaconda.org/conda-forge/bhklab-project-template)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/bhklab-project-template)](https://pypi.org/project/bhklab-project-template/)

## Conda-forge Build status

Link to the [feedstock-repo](https://github.com/conda-forge/bhklab-project-template-feedstock)

<table><tr><td>All platforms:</td>
    <td>
      <a href="https://dev.azure.com/conda-forge/feedstock-builds/_build/latest?definitionId=25690&branchName=main">
        <img src="https://dev.azure.com/conda-forge/feedstock-builds/_apis/build/status/bhklab-project-template-feedstock?branchName=main">
      </a>
    </td>
  </tr>
</table>

Checkout the [documentation](https://bhklab.github.io/bhklab-project-template/) for more information.
